summaryrefslogtreecommitdiff
path: root/libs/ardour/port_insert.cc
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2010-12-16 12:48:50 +0000
committerCarl Hetherington <carl@carlh.net>2010-12-16 12:48:50 +0000
commitb3fcaf71d4ce6ed9e90c8cab14cd6c81f65a50c6 (patch)
treecb33365e1e984344009983d62e0cf27c88c0ba19 /libs/ardour/port_insert.cc
parent9e4b7a45fee81854d5dc395e3df6b3ba6cc570ac (diff)
Fix loading of PortInserts from 2.X sessions.
git-svn-id: svn://localhost/ardour2/branches/3.0@8287 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/port_insert.cc')
-rw-r--r--libs/ardour/port_insert.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/libs/ardour/port_insert.cc b/libs/ardour/port_insert.cc
index 492fca2723..f0940670d4 100644
--- a/libs/ardour/port_insert.cc
+++ b/libs/ardour/port_insert.cc
@@ -184,9 +184,9 @@ PortInsert::set_state (const XMLNode& node, int version)
const XMLNode* insert_node = &node;
// legacy sessions: search for child IOProcessor node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {
- if ((*niter)->name() == "IOProcessor") {
+ if ((*niter)->name() == "Redirect") {
insert_node = *niter;
break;
}
@@ -184,9 +184,9 @@ PortInsert::set_state (const XMLNode& node, int version)
const XMLNode* insert_node = &node;
- // legacy sessions: search for child IOProcessor node
+ // legacy sessions: search for child Redirect node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {